==> haskell-lambdabot-trusted-5.3.1.2-235-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-lambdabot-trusted.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 lambdabot-trusted
version:              5.3.1.2
visibility:           public
id:                   lambdabot-trusted-5.3.1.2-98WPxjfk2n88nx1ipqlFoX
key:                  lambdabot-trusted-5.3.1.2-98WPxjfk2n88nx1ipqlFoX
license:              LicenseRef-GPL
maintainer:           Naïm Favier <n@monade.li>
author:               Bertram Felgenhauer
homepage:             https://wiki.haskell.org/Lambdabot
synopsis:             Lambdabot trusted code.
description:
    Lambdabot is an IRC bot written over several years by
    those on the #haskell IRC channel.

    This small package provides functions used by
    the \@run command.

category:             Development, Web
abi:                  f5a15b39a0dfa0822275220a74c5760a
exposed:              True
exposed-modules:      Lambdabot.Plugin.Haskell.Eval.Trusted
hidden-modules:       Lambdabot.Plugin.Haskell.Check.ShowQ
import-dirs:          /usr/lib/ghc-9.6.6/site-local/lambdabot-trusted-5.3.1.2
library-dirs:         /usr/lib/ghc-9.6.6/site-local/lambdabot-trusted-5.3.1.2
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/lambdabot-trusted-5.3.1.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-lambdabot-trusted
hs-libraries:         HSlambdabot-trusted-5.3.1.2-98WPxjfk2n88nx1ipqlFoX
depends:
    QuickCheck-2.15.0.1-DMgRmI5QzBCFdvvi5liF0L
    QuickCheck-safe-0.1.0.6-6Ng8zOzIi07898IC0oxutO base-4.18.2.1
    oeis-0.3.10.1-KZe9qkpdGckykTX9c0186

haddock-interfaces:
    /usr/share/doc/haskell-lambdabot-trusted/html/lambdabot-trusted.haddock

haddock-html:         /usr/share/doc/haskell-lambdabot-trusted/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-lambdabot-trusted-5.3.1.2-236-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-lambdabot-trusted.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 lambdabot-trusted
version:              5.3.1.2
visibility:           public
id:                   lambdabot-trusted-5.3.1.2-E6cxOZSpkiqHvlGdzm2Xnj
key:                  lambdabot-trusted-5.3.1.2-E6cxOZSpkiqHvlGdzm2Xnj
license:              LicenseRef-GPL
maintainer:           Naïm Favier <n@monade.li>
author:               Bertram Felgenhauer
homepage:             https://wiki.haskell.org/Lambdabot
synopsis:             Lambdabot trusted code.
description:
    Lambdabot is an IRC bot written over several years by
    those on the #haskell IRC channel.

    This small package provides functions used by
    the \@run command.

category:             Development, Web
abi:                  216f6c82d747ddafb1804bca75086ec7
exposed:              True
exposed-modules:      Lambdabot.Plugin.Haskell.Eval.Trusted
hidden-modules:       Lambdabot.Plugin.Haskell.Check.ShowQ
import-dirs:          /usr/lib/ghc-9.6.6/site-local/lambdabot-trusted-5.3.1.2
library-dirs:         /usr/lib/ghc-9.6.6/site-local/lambdabot-trusted-5.3.1.2
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/lambdabot-trusted-5.3.1.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-lambdabot-trusted
hs-libraries:         HSlambdabot-trusted-5.3.1.2-E6cxOZSpkiqHvlGdzm2Xnj
depends:
    QuickCheck-2.15.0.1-1xFq7rzYyJMIIsLto0YgsS
    QuickCheck-safe-0.1.0.6-FOVX1MeRANYE57eCw8qL73 base-4.18.2.1
    oeis-0.3.10.1-Yt7e0DePOMFUvgKWi5wc8

haddock-interfaces:
    /usr/share/doc/haskell-lambdabot-trusted/html/lambdabot-trusted.haddock

haddock-html:         /usr/share/doc/haskell-lambdabot-trusted/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
